ewa.ply.yacc.Grammar

Package ewa :: Package ply :: Module yacc :: Class Grammar |
[hide private]
[frames] | no frames]

# Class Grammar

source code

    object --+
             |
            Grammar

Instance Methods | [hide private]
__init__(self, terminals) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__len__(self) | source code
__getitem__(self, index) | source code
set_precedence(self, term, assoc, level) | source code
add_production(self, prodname, syms, func=None, file=`'````'`, line=0) | source code
set_start(self, start=None) | source code
find_unreachable(self) | source code
infinite_cycles(self) | source code
undefined_symbols(self) | source code
unused_terminals(self) | source code
unused_rules(self) | source code
unused_precedence(self) | source code
_first(self, beta) | source code
compute_first(self) | source code
compute_follow(self, start=None) | source code
build_lritems(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, terminals) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)